==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appstream/kotlin/inputs/FleetDomainJoinInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appstream.kotlin.inputs

import com.pulumi.aws.appstream.inputs.FleetDomainJoinInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property directoryName Fully qualified name of the directory (for example, corp.example.com).
 * @property organizationalUnitDistinguishedName Distinguished name of the organizational unit for computer accounts.
 */
public data class FleetDomainJoinInfoArgs(
    public val directoryName: Output<String>? = null,
    public val organizationalUnitDistinguishedName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appstream.inputs.FleetDomainJoinInfoArgs> {
    override fun toJava(): com.pulumi.aws.appstream.inputs.FleetDomainJoinInfoArgs =
        com.pulumi.aws.appstream.inputs.FleetDomainJoinInfoArgs.builder()
            .directoryName(directoryName?.applyValue({ args0 -> args0 }))
            .organizationalUnitDistinguishedName(
                organizationalUnitDistinguishedName?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [FleetDomainJoinInfoArgs].
 */
@PulumiTagMarker
public class FleetDomainJoinInfoArgsBuilder internal constructor() {
    private var directoryName: Output<String>? = null

    private var organizationalUnitDistinguishedName: Output<String>? = null

    /**
     * @param value Fully qualified name of the directory (for example, corp.example.com).
     */
    @JvmName("ctdbifgbcyuspxsv")
    public suspend fun directoryName(`value`: Output<String>) {
        this.directoryName = value
    }

    /**
     * @param value Distinguished name of the organizational unit for computer accounts.
     */
    @JvmName("agffunondxjvysha")
    public suspend fun organizationalUnitDistinguishedName(`value`: Output<String>) {
        this.organizationalUnitDistinguishedName = value
    }

    /**
     * @param value Fully qualified name of the directory (for example, corp.example.com).
     */
    @JvmName("frxaoqwdlchwudix")
    public suspend fun directoryName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.directoryName = mapped
    }

    /**
     * @param value Distinguished name of the organizational unit for computer accounts.
     */
    @JvmName("lvxfnahfasdxktsy")
    public suspend fun organizationalUnitDistinguishedName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.organizationalUnitDistinguishedName = mapped
    }

    internal fun build(): FleetDomainJoinInfoArgs = FleetDomainJoinInfoArgs(
        directoryName = directoryName,
        organizationalUnitDistinguishedName = organizationalUnitDistinguishedName,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appstream/kotlin/inputs/FleetDomainJoinInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appstream.kotlin.inputs

import com.pulumi.aws.appstream.inputs.FleetDomainJoinInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property directoryName Fully qualified name of the directory (for example, corp.example.com).
 * @property organizationalUnitDistinguishedName Distinguished name of the organizational unit for computer accounts.
 */
public data class FleetDomainJoinInfoArgs(
    public val directoryName: Output<String>? = null,
    public val organizationalUnitDistinguishedName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appstream.inputs.FleetDomainJoinInfoArgs> {
    override fun toJava(): com.pulumi.aws.appstream.inputs.FleetDomainJoinInfoArgs =
        com.pulumi.aws.appstream.inputs.FleetDomainJoinInfoArgs.builder()
            .directoryName(directoryName?.applyValue({ args0 -> args0 }))
            .organizationalUnitDistinguishedName(
                organizationalUnitDistinguishedName?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [FleetDomainJoinInfoArgs].
 */
@PulumiTagMarker
public class FleetDomainJoinInfoArgsBuilder internal constructor() {
    private var directoryName: Output<String>? = null

    private var organizationalUnitDistinguishedName: Output<String>? = null

    /**
     * @param value Fully qualified name of the directory (for example, corp.example.com).
     */
    @JvmName("uaspaoprddvhubvb")
    public suspend fun directoryName(`value`: Output<String>) {
        this.directoryName = value
    }

    /**
     * @param value Distinguished name of the organizational unit for computer accounts.
     */
    @JvmName("ehmstybdvtpiktsh")
    public suspend fun organizationalUnitDistinguishedName(`value`: Output<String>) {
        this.organizationalUnitDistinguishedName = value
    }

    /**
     * @param value Fully qualified name of the directory (for example, corp.example.com).
     */
    @JvmName("aueyvrdtsujbiocx")
    public suspend fun directoryName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.directoryName = mapped
    }

    /**
     * @param value Distinguished name of the organizational unit for computer accounts.
     */
    @JvmName("kqmejjpwejhnuawa")
    public suspend fun organizationalUnitDistinguishedName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.organizationalUnitDistinguishedName = mapped
    }

    internal fun build(): FleetDomainJoinInfoArgs = FleetDomainJoinInfoArgs(
        directoryName = directoryName,
        organizationalUnitDistinguishedName = organizationalUnitDistinguishedName,
    )
}
